==> nodejs_interop-0.4.0.tar.gz: lib/src/node/fs/options.dart <==
part of nodejs_interop.node.fs;

/// Options used to customize the file reading.
@JS()
@anonymous
class ReadOptions {

  /// Creates a new options object.
  external factory ReadOptions({String encoding, String flag = 'r'});

  /// The encoding of the returned contents. If no encoding is specified, then the raw buffer is returned.
  external String get encoding;

  /// Value indicating the behavior of the file to be opened.
  external String get flag;
}

/// Options used to customize a file system watcher.
@JS()
@anonymous
class WatchOptions {

  /// Creates a new options object.
  external factory WatchOptions({
    String encoding = BufferEncoding.utf8,
    bool persistent = true,
    bool recursive = false
  });

  /// The character encoding to be used for the `filename` passed to the listener.
  external String get encoding;

  /// Whether the process should continue to run as long as files are being watched.
  external bool get persistent;

  /// Whether all subdirectories should be watched, or only the current directory.
  /// This applies when a directory is specified, and only on supported platforms.
  external bool get recursive;
}

/// Options used to customize the file writing.
@JS()
@anonymous
class WriteOptions {

  /// Creates a new options object.
  external factory WriteOptions({String encoding = BufferEncoding.utf8, String flag, int mode = 0x1B6});

  /// The encoding of the written contents.
  external String get encoding;

  /// Value indicating the behavior of the file to be opened.
  external String get flag;

  /// The file permissions.
  external int get mode;
}

==> nodejs_interop-0.5.0.tar.gz: lib/src/node/fs/options.dart <==
part of nodejs_interop.node.fs;

/// Options used to customize the creation of a file stream.
@JS()
@anonymous
class CreateStreamOptions {

  /// Creates a new options object.
  external factory CreateStreamOptions({
    bool autoClose = true,
    String encoding,
    int end,
    int fd,
    String flags,
    int mode = 0x1B6,
    int start
  });

  /// Value indicating whether the file descriptor will be closed automatically.
  external bool get autoClose;

  /// The encoding of the stream contents.
  external String get encoding;

  /// The file position where to end.
  /// Not supported by the [FSModule.createWriteStream] method.
  external int get end;

  /// A file descriptor. If specified, the file path will be ignored.
  external int get fd;

  /// Value indicating the behavior of the file to be opened.
  external String get flags;

  /// The file permissions.
  external int get mode;

  /// The file position where to start.
  external int get start;
}

/// Options used to customize the file reading.
@JS()
@anonymous
class ReadOptions {

  /// Creates a new options object.
  external factory ReadOptions({String encoding, String flag = 'r'});

  /// The encoding of the returned contents. If no encoding is specified, then the raw buffer is returned.
  external String get encoding;

  /// Value indicating the behavior of the file to be opened.
  external String get flag;
}

/// Options used to customize a file system entity watcher.
@JS()
@anonymous
class WatchOptions {

  /// Creates a new options object.
  external factory WatchOptions({
    String encoding = BufferEncoding.utf8,
    bool persistent = true,
    bool recursive = false
  });

  /// The character encoding to be used for the `filename` passed to the listener.
  external String get encoding;

  /// Whether the process should continue to run as long as files are being watched.
  external bool get persistent;

  /// Whether all subdirectories should be watched, or only the current directory.
  /// This applies when a directory is specified, and only on supported platforms.
  external bool get recursive;
}

/// Options used to customize a file watcher.
@JS()
@anonymous
class WatchFileOptions {

  /// Creates a new options object.
  external factory WatchFileOptions({
    int interval = 5007,
    bool persistent = true
  });

  /// Value indicating how often the target should be polled in milliseconds.
  external int get interval;

  /// Whether the process should continue to run as long as the file is being watched.
  external bool get persistent;
}

/// Options used to customize the file writing.
@JS()
@anonymous
class WriteOptions {

  /// Creates a new options object.
  external factory WriteOptions({String encoding = BufferEncoding.utf8, String flag, int mode = 0x1B6});

  /// The encoding of the written contents.
  external String get encoding;

  /// Value indicating the behavior of the file to be opened.
  external String get flag;

  /// The file permissions.
  external int get mode;
}
